@@ -134,6 +134,13 @@ class HardwareVEML7700Form(HardwareForm):
         model = VEML7700
         fields = ("__all__")
 
+class HardwarePMSA0031Form(HardwareForm):
+    def __init__(self, *args, **kwargs):
+        super(HardwarePMSA0031Form, self).__init__(*args, **kwargs)
+
+    class Meta:
+        model = VEML7700
+        fields = ("__all__")
 
 class AccessoryForm(forms.ModelForm):
 
